@@ -9,7 +9,6 @@ import uuid
 import git
 from git.cmd import Git
 from git.compat import (
-    string_types,
     defenc,
     is_win,
 )
@@ -21,7 +20,8 @@ from git.config import (
 from git.exc import (
     InvalidGitRepositoryError,
     NoSuchPathError,
-    RepositoryDirtyError
+    RepositoryDirtyError,
+    BadName
 )
 from git.objects.base import IndexObject, Object
 from git.objects.util import Traversable
@@ -110,7 +110,7 @@ class Submodule(IndexObject, Iterable, Traversable):
         if url is not None:
             self._url = url
         if branch_path is not None:
-            assert isinstance(branch_path, string_types)
+            assert isinstance(branch_path, str)
             self._branch_path = branch_path
         if name is not None:
             self._name = name
@@ -309,7 +309,7 @@ class Submodule(IndexObject, Iterable, Traversable):
     #{ Edit Interface
 
     @classmethod
-    def add(cls, repo, name, path, url=None, branch=None, no_checkout=False):
+    def add(cls, repo, name, path, url=None, branch=None, no_checkout=False, depth=None):
         """Add a new submodule to the given repository. This will alter the index
         as well as the .gitmodules file, but will not create a new commit.
         If the submodule already exists, no matter if the configuration differs
@@ -334,6 +334,8 @@ class Submodule(IndexObject, Iterable, Traversable):
             Examples are 'master' or 'feature/new'
         :param no_checkout: if True, and if the repository has to be cloned manually,
             no checkout will be performed
+        :param depth: Create a shallow clone with a history truncated to the
+            specified number of commits.
         :return: The newly created submodule instance
         :note: works atomically, such that no change will be done if the repository
             update fails for instance"""
@@ -395,6 +397,12 @@ class Submodule(IndexObject, Iterable, Traversable):
                 kwargs['b'] = br.name
             # END setup checkout-branch
 
+            if depth:
+                if isinstance(depth, int):
+                    kwargs['depth'] = depth
+                else:
+                    raise ValueError("depth should be an integer")
+
             # _clone_repo(cls, repo, url, path, name, **kwargs):
             mrepo = cls._clone_repo(repo, url, path, name, **kwargs)
         # END verify url
@@ -539,7 +547,7 @@ class Submodule(IndexObject, Iterable, Traversable):
                         mrepo.head.set_reference(local_branch, logmsg="submodule: attaching head to %s" % local_branch)
                         mrepo.head.ref.set_tracking_branch(remote_branch)
                     except (IndexError, InvalidGitRepositoryError):
-                        log.warn("Failed to checkout tracking branch %s", self.branch_path)
+                        log.warning("Failed to checkout tracking branch %s", self.branch_path)
                     # END handle tracking branch
 
                     # NOTE: Have to write the repo config file as well, otherwise
@@ -1154,10 +1162,10 @@ class Submodule(IndexObject, Iterable, Traversable):
     @classmethod
     def iter_items(cls, repo, parent_commit='HEAD'):
         """:return: iterator yielding Submodule instances available in the given repository"""
-        pc = repo.commit(parent_commit)         # parent commit instance
         try:
+            pc = repo.commit(parent_commit)         # parent commit instance
             parser = cls._config_parser(repo, pc, read_only=True)
-        except IOError:
+        except (IOError, BadName):
             return
         # END handle empty iterator
 
