@@ -232,7 +232,7 @@ class Tutorials(TestBase):
         # [6-test_references_and_objects]
         new_tag = repo.create_tag('my_new_tag', message='my message')
         # You cannot change the commit a tag points to. Tags need to be re-created
-        self.failUnlessRaises(AttributeError, setattr, new_tag, 'commit', repo.commit('HEAD~1'))
+        self.assertRaises(AttributeError, setattr, new_tag, 'commit', repo.commit('HEAD~1'))
         repo.delete_tag(new_tag)
         # ![6-test_references_and_objects]
 
@@ -320,10 +320,10 @@ class Tutorials(TestBase):
         self.assertEqual(tree['smmap'], tree / 'smmap')          # access by index and by sub-path
         for entry in tree:                                         # intuitive iteration of tree members
             print(entry)
-        blob = tree.trees[0].blobs[0]                              # let's get a blob in a sub-tree
+        blob = tree.trees[1].blobs[0]                              # let's get a blob in a sub-tree
         assert blob.name
         assert len(blob.path) < len(blob.abspath)
-        self.assertEqual(tree.trees[0].name + '/' + blob.name, blob.path)   # this is how relative blob path generated
+        self.assertEqual(tree.trees[1].name + '/' + blob.name, blob.path)   # this is how relative blob path generated
         self.assertEqual(tree[blob.path], blob)                             # you can use paths like 'dir/file' in tree
         # ![19-test_references_and_objects]
 
@@ -441,7 +441,7 @@ class Tutorials(TestBase):
 
         # [30-test_references_and_objects]
         # checkout the branch using git-checkout. It will fail as the working tree appears dirty
-        self.failUnlessRaises(git.GitCommandError, repo.heads.master.checkout)
+        self.assertRaises(git.GitCommandError, repo.heads.master.checkout)
         repo.heads.past_branch.checkout()
         # ![30-test_references_and_objects]
 
