@@ -8,6 +8,7 @@ import os
 import subprocess
 import sys
 from tempfile import TemporaryFile
+from unittest import mock
 
 from git import (
     Git,
@@ -17,14 +18,9 @@ from git import (
     Repo,
     cmd
 )
-from git.compat import PY3, is_darwin
+from git.compat import is_darwin
 from git.test.lib import (
     TestBase,
-    patch,
-    raises,
-    assert_equal,
-    assert_true,
-    assert_match,
     fixture_path
 )
 from git.test.lib import with_rw_directory
@@ -32,12 +28,6 @@ from git.util import finalize_process
 
 import os.path as osp
 
-
-try:
-    from unittest import mock
-except ImportError:
-    import mock
-
 from git.compat import is_win
 
 
@@ -52,70 +42,62 @@ class TestGit(TestBase):
         import gc
         gc.collect()
 
-    @patch.object(Git, 'execute')
+    @mock.patch.object(Git, 'execute')
     def test_call_process_calls_execute(self, git):
         git.return_value = ''
         self.git.version()
-        assert_true(git.called)
-        assert_equal(git.call_args, ((['git', 'version'],), {}))
+        self.assertTrue(git.called)
+        self.assertEqual(git.call_args, ((['git', 'version'],), {}))
 
     def test_call_unpack_args_unicode(self):
-        args = Git._Git__unpack_args(u'Unicode€™')
-        if PY3:
-            mangled_value = 'Unicode\u20ac\u2122'
-        else:
-            mangled_value = 'Unicode\xe2\x82\xac\xe2\x84\xa2'
-        assert_equal(args, [mangled_value])
+        args = Git._Git__unpack_args('Unicode€™')
+        mangled_value = 'Unicode\u20ac\u2122'
+        self.assertEqual(args, [mangled_value])
 
     def test_call_unpack_args(self):
-        args = Git._Git__unpack_args(['git', 'log', '--', u'Unicode€™'])
-        if PY3:
-            mangled_value = 'Unicode\u20ac\u2122'
-        else:
-            mangled_value = 'Unicode\xe2\x82\xac\xe2\x84\xa2'
-        assert_equal(args, ['git', 'log', '--', mangled_value])
+        args = Git._Git__unpack_args(['git', 'log', '--', 'Unicode€™'])
+        mangled_value = 'Unicode\u20ac\u2122'
+        self.assertEqual(args, ['git', 'log', '--', mangled_value])
 
-    @raises(GitCommandError)
     def test_it_raises_errors(self):
-        self.git.this_does_not_exist()
+        self.assertRaises(GitCommandError, self.git.this_does_not_exist)
 
     def test_it_transforms_kwargs_into_git_command_arguments(self):
-        assert_equal(["-s"], self.git.transform_kwargs(**{'s': True}))
-        assert_equal(["-s", "5"], self.git.transform_kwargs(**{'s': 5}))
-        assert_equal([], self.git.transform_kwargs(**{'s': None}))
+        self.assertEqual(["-s"], self.git.transform_kwargs(**{'s': True}))
+        self.assertEqual(["-s", "5"], self.git.transform_kwargs(**{'s': 5}))
+        self.assertEqual([], self.git.transform_kwargs(**{'s': None}))
 
-        assert_equal(["--max-count"], self.git.transform_kwargs(**{'max_count': True}))
-        assert_equal(["--max-count=5"], self.git.transform_kwargs(**{'max_count': 5}))
-        assert_equal(["--max-count=0"], self.git.transform_kwargs(**{'max_count': 0}))
-        assert_equal([], self.git.transform_kwargs(**{'max_count': None}))
+        self.assertEqual(["--max-count"], self.git.transform_kwargs(**{'max_count': True}))
+        self.assertEqual(["--max-count=5"], self.git.transform_kwargs(**{'max_count': 5}))
+        self.assertEqual(["--max-count=0"], self.git.transform_kwargs(**{'max_count': 0}))
+        self.assertEqual([], self.git.transform_kwargs(**{'max_count': None}))
 
         # Multiple args are supported by using lists/tuples
-        assert_equal(["-L", "1-3", "-L", "12-18"], self.git.transform_kwargs(**{'L': ('1-3', '12-18')}))
-        assert_equal(["-C", "-C"], self.git.transform_kwargs(**{'C': [True, True, None, False]}))
+        self.assertEqual(["-L", "1-3", "-L", "12-18"], self.git.transform_kwargs(**{'L': ('1-3', '12-18')}))
+        self.assertEqual(["-C", "-C"], self.git.transform_kwargs(**{'C': [True, True, None, False]}))
 
         # order is undefined
         res = self.git.transform_kwargs(**{'s': True, 't': True})
         self.assertEqual({'-s', '-t'}, set(res))
 
     def test_it_executes_git_to_shell_and_returns_result(self):
-        assert_match(r'^git version [\d\.]{2}.*$', self.git.execute(["git", "version"]))
+        self.assertRegex(self.git.execute(["git", "version"]), r'^git version [\d\.]{2}.*$')
 
     def test_it_accepts_stdin(self):
         filename = fixture_path("cat_file_blob")
         with open(filename, 'r') as fh:
-            assert_equal("70c379b63ffa0795fdbfbc128e5a2818397b7ef8",
-                         self.git.hash_object(istream=fh, stdin=True))
+            self.assertEqual("70c379b63ffa0795fdbfbc128e5a2818397b7ef8",
+                             self.git.hash_object(istream=fh, stdin=True))
 
-    @patch.object(Git, 'execute')
+    @mock.patch.object(Git, 'execute')
     def test_it_ignores_false_kwargs(self, git):
         # this_should_not_be_ignored=False implies it *should* be ignored
         self.git.version(pass_this_kwarg=False)
-        assert_true("pass_this_kwarg" not in git.call_args[1])
+        self.assertTrue("pass_this_kwarg" not in git.call_args[1])
 
-    @raises(GitCommandError)
     def test_it_raises_proper_exception_with_output_stream(self):
         tmp_file = TemporaryFile()
-        self.git.checkout('non-existent-branch', output_stream=tmp_file)
+        self.assertRaises(GitCommandError, self.git.checkout, 'non-existent-branch', output_stream=tmp_file)
 
     def test_it_accepts_environment_variables(self):
         filename = fixture_path("ls_tree_empty")
@@ -130,7 +112,7 @@ class TestGit(TestBase):
                 'GIT_COMMITTER_DATE': '1500000000+0000',
             }
             commit = self.git.commit_tree(tree, m='message', env=env)
-            assert_equal(commit, '4cfd6b0314682d5a58f80be39850bad1640e9241')
+            self.assertEqual(commit, '4cfd6b0314682d5a58f80be39850bad1640e9241')
 
     def test_persistent_cat_file_command(self):
         # read header only
@@ -181,7 +163,7 @@ class TestGit(TestBase):
             # set it to something that doens't exist, assure it raises
             type(self.git).GIT_PYTHON_GIT_EXECUTABLE = osp.join(
                 "some", "path", "which", "doesn't", "exist", "gitbinary")
-            self.failUnlessRaises(exc, self.git.version)
+            self.assertRaises(exc, self.git.version)
         finally:
             type(self.git).GIT_PYTHON_GIT_EXECUTABLE = prev_cmd
         # END undo adjustment
@@ -199,17 +181,17 @@ class TestGit(TestBase):
         # This work because any command after git --version is ignored
         git_version = self.git(version=True).NoOp()
         git_command_version = self.git.version()
-        self.assertEquals(git_version, git_command_version)
+        self.assertEqual(git_version, git_command_version)
 
     def test_persistent_options(self):
         git_command_version = self.git.version()
         # analog to test_options_are_passed_to_git
         self.git.set_persistent_git_options(version=True)
         git_version = self.git.NoOp()
-        self.assertEquals(git_version, git_command_version)
+        self.assertEqual(git_version, git_command_version)
         # subsequent calls keep this option:
         git_version_2 = self.git.NoOp()
-        self.assertEquals(git_version_2, git_command_version)
+        self.assertEqual(git_version_2, git_command_version)
 
         # reset to empty:
         self.git.set_persistent_git_options()
@@ -218,14 +200,14 @@ class TestGit(TestBase):
     def test_single_char_git_options_are_passed_to_git(self):
         input_value = 'TestValue'
         output_value = self.git(c='user.name=%s' % input_value).config('--get', 'user.name')
-        self.assertEquals(input_value, output_value)
+        self.assertEqual(input_value, output_value)
 
     def test_change_to_transform_kwargs_does_not_break_command_options(self):
         self.git.log(n=1)
 
     def test_insert_after_kwarg_raises(self):
         # This isn't a complete add command, which doesn't matter here
-        self.failUnlessRaises(ValueError, self.git.remote, 'add', insert_kwargs_after='foo')
+        self.assertRaises(ValueError, self.git.remote, 'add', insert_kwargs_after='foo')
 
     def test_env_vars_passed_to_git(self):
         editor = 'non_existent_editor'
