@@ -25,7 +25,7 @@ from git import (
     GitCommandError,
     CheckoutError,
 )
-from git.compat import string_types, is_win, PY3
+from git.compat import is_win
 from git.exc import (
     HookExecutionError,
     InvalidGitRepositoryError
@@ -205,7 +205,7 @@ class TestIndex(TestBase):
             assert blob.path.startswith(prefix)
 
         # writing a tree should fail with an unmerged index
-        self.failUnlessRaises(UnmergedEntriesError, three_way_index.write_tree)
+        self.assertRaises(UnmergedEntriesError, three_way_index.write_tree)
 
         # removed unmerged entries
         unmerged_blob_map = three_way_index.unmerged_blobs()
@@ -265,13 +265,13 @@ class TestIndex(TestBase):
         # a three way merge would result in a conflict and fails as the command will
         # not overwrite any entries in our index and hence leave them unmerged. This is
         # mainly a protection feature as the current index is not yet in a tree
-        self.failUnlessRaises(GitCommandError, index.merge_tree, next_commit, base=parent_commit)
+        self.assertRaises(GitCommandError, index.merge_tree, next_commit, base=parent_commit)
 
         # the only way to get the merged entries is to safe the current index away into a tree,
         # which is like a temporary commit for us. This fails as well as the NULL sha deos not
         # have a corresponding object
         # NOTE: missing_ok is not a kwarg anymore, missing_ok is always true
-        # self.failUnlessRaises(GitCommandError, index.write_tree)
+        # self.assertRaises(GitCommandError, index.write_tree)
 
         # if missing objects are okay, this would work though ( they are always okay now )
         # As we can't read back the tree with NULL_SHA, we rather set it to something else
@@ -326,7 +326,7 @@ class TestIndex(TestBase):
         assert wdiff != odiff
 
         # against something unusual
-        self.failUnlessRaises(ValueError, index.diff, int)
+        self.assertRaises(ValueError, index.diff, int)
 
         # adjust the index to match an old revision
         cur_branch = rw_repo.active_branch
@@ -375,8 +375,8 @@ class TestIndex(TestBase):
         assert osp.exists(test_file)
 
         # checking out non-existing file throws
-        self.failUnlessRaises(CheckoutError, index.checkout, "doesnt_exist_ever.txt.that")
-        self.failUnlessRaises(CheckoutError, index.checkout, paths=["doesnt/exist"])
+        self.assertRaises(CheckoutError, index.checkout, "doesnt_exist_ever.txt.that")
+        self.assertRaises(CheckoutError, index.checkout, paths=["doesnt/exist"])
 
         # checkout file with modifications
         append_data = b"hello"
@@ -388,7 +388,7 @@ class TestIndex(TestBase):
             self.assertEqual(len(e.failed_files), 1)
             self.assertEqual(e.failed_files[0], osp.basename(test_file))
             self.assertEqual(len(e.failed_files), len(e.failed_reasons))
-            self.assertIsInstance(e.failed_reasons[0], string_types)
+            self.assertIsInstance(e.failed_reasons[0], str)
             self.assertEqual(len(e.valid_files), 0)
             with open(test_file, 'rb') as fd:
                 s = fd.read()
@@ -429,7 +429,7 @@ class TestIndex(TestBase):
         num_entries = len(index.entries)
         cur_head = rw_repo.head
 
-        uname = u"Thomas Müller"
+        uname = "Thomas Müller"
         umail = "sd@company.com"
         with rw_repo.config_writer() as writer:
             writer.set_value("user", "name", uname)
@@ -474,17 +474,17 @@ class TestIndex(TestBase):
         self.assertEqual(self._count_existing(rw_repo, deleted_files), len(deleted_files))
 
         # invalid type
-        self.failUnlessRaises(TypeError, index.remove, [1])
+        self.assertRaises(TypeError, index.remove, [1])
 
         # absolute path
         deleted_files = index.remove([osp.join(rw_repo.working_tree_dir, "lib")], r=True)
         assert len(deleted_files) > 1
-        self.failUnlessRaises(ValueError, index.remove, ["/doesnt/exists"])
+        self.assertRaises(ValueError, index.remove, ["/doesnt/exists"])
 
         # TEST COMMITTING
         # commit changed index
         cur_commit = cur_head.commit
-        commit_message = u"commit default head by Frèderic Çaufl€"
+        commit_message = "commit default head by Frèderic Çaufl€"
 
         new_commit = index.commit(commit_message, head=False)
         assert cur_commit != new_commit
@@ -500,13 +500,13 @@ class TestIndex(TestBase):
         # commit with other actor
         cur_commit = cur_head.commit
 
-        my_author = Actor(u"Frèderic Çaufl€", "author@example.com")
-        my_committer = Actor(u"Committing Frèderic Çaufl€", "committer@example.com")
+        my_author = Actor("Frèderic Çaufl€", "author@example.com")
+        my_committer = Actor("Committing Frèderic Çaufl€", "committer@example.com")
         commit_actor = index.commit(commit_message, author=my_author, committer=my_committer)
         assert cur_commit != commit_actor
-        self.assertEqual(commit_actor.author.name, u"Frèderic Çaufl€")
+        self.assertEqual(commit_actor.author.name, "Frèderic Çaufl€")
         self.assertEqual(commit_actor.author.email, "author@example.com")
-        self.assertEqual(commit_actor.committer.name, u"Committing Frèderic Çaufl€")
+        self.assertEqual(commit_actor.committer.name, "Committing Frèderic Çaufl€")
         self.assertEqual(commit_actor.committer.email, "committer@example.com")
         self.assertEqual(commit_actor.message, commit_message)
         self.assertEqual(commit_actor.parents[0], cur_commit)
@@ -516,7 +516,7 @@ class TestIndex(TestBase):
 
         # commit with author_date and commit_date
         cur_commit = cur_head.commit
-        commit_message = u"commit with dates by Avinash Sajjanshetty"
+        commit_message = "commit with dates by Avinash Sajjanshetty"
 
         new_commit = index.commit(commit_message, author_date="2006-04-07T22:13:13", commit_date="2005-04-07T22:13:13")
         assert cur_commit != new_commit
@@ -571,7 +571,7 @@ class TestIndex(TestBase):
         self.assertEqual(len(entries), 2)
 
         # missing path
-        self.failUnlessRaises(OSError, index.reset(new_commit).add, ['doesnt/exist/must/raise'])
+        self.assertRaises(OSError, index.reset(new_commit).add, ['doesnt/exist/must/raise'])
 
         # blob from older revision overrides current index revision
         old_blob = new_commit.parents[0].tree.blobs[0]
@@ -584,7 +584,7 @@ class TestIndex(TestBase):
         # mode 0 not allowed
         null_hex_sha = Diff.NULL_HEX_SHA
         null_bin_sha = b"\0" * 20
-        self.failUnlessRaises(ValueError, index.reset(
+        self.assertRaises(ValueError, index.reset(
             new_commit).add, [BaseIndexEntry((0, null_bin_sha, 0, "doesntmatter"))])
 
         # add new file
@@ -595,7 +595,7 @@ class TestIndex(TestBase):
         self._assert_entries(entries)
         self._assert_fprogress(entries)
         self.assertEqual(len(entries), 1)
-        self.assertNotEquals(entries[0].hexsha, null_hex_sha)
+        self.assertNotEqual(entries[0].hexsha, null_hex_sha)
 
         # add symlink
         if not is_win:
@@ -668,10 +668,10 @@ class TestIndex(TestBase):
             # END for each renamed item
         # END move assertion utility
 
-        self.failUnlessRaises(ValueError, index.move, ['just_one_path'])
+        self.assertRaises(ValueError, index.move, ['just_one_path'])
         # file onto existing file
         files = ['AUTHORS', 'LICENSE']
-        self.failUnlessRaises(GitCommandError, index.move, files)
+        self.assertRaises(GitCommandError, index.move, files)
 
         # again, with force
         assert_mv_rval(index.move(files, f=True))
@@ -777,7 +777,7 @@ class TestIndex(TestBase):
     def test_index_single_addremove(self, rw_repo):
         fp = osp.join(rw_repo.working_dir, 'testfile.txt')
         with open(fp, 'w') as fs:
-            fs.write(u'content of testfile')
+            fs.write('content of testfile')
         self._assert_entries(rw_repo.index.add(fp))
         deleted_files = rw_repo.index.remove(fp)
         assert deleted_files
@@ -821,16 +821,12 @@ class TestIndex(TestBase):
             asserted = True
         assert asserted, "Adding using a filename is not correctly asserted."
 
-    @skipIf(HIDE_WINDOWS_KNOWN_ERRORS and not PY3, r"""
-        FIXME:  File "C:\projects\gitpython\git\util.py", line 125, in to_native_path_linux
-        return path.replace('\\', '/')
-        UnicodeDecodeError: 'ascii' codec can't decode byte 0xc3 in position 0: ordinal not in range(128)""")
     @with_rw_directory
     def test_add_utf8P_path(self, rw_dir):
         # NOTE: fp is not a Unicode object in python 2 (which is the source of the problem)
         fp = osp.join(rw_dir, 'ø.txt')
         with open(fp, 'wb') as fs:
-            fs.write(u'content of ø'.encode('utf-8'))
+            fs.write('content of ø'.encode('utf-8'))
 
         r = Repo.init(rw_dir)
         r.index.add([fp])
@@ -900,8 +896,8 @@ class TestIndex(TestBase):
 
     @with_rw_repo('HEAD', bare=True)
     def test_commit_msg_hook_success(self, rw_repo):
-        commit_message = u"commit default head by Frèderic Çaufl€"
-        from_hook_message = u"from commit-msg"
+        commit_message = "commit default head by Frèderic Çaufl€"
+        from_hook_message = "from commit-msg"
         index = rw_repo.index
         _make_hook(
             index.repo.git_dir,
@@ -909,7 +905,7 @@ class TestIndex(TestBase):
             'printf " {}" >> "$1"'.format(from_hook_message)
         )
         new_commit = index.commit(commit_message)
-        self.assertEqual(new_commit.message, u"{} {}".format(commit_message, from_hook_message))
+        self.assertEqual(new_commit.message, "{} {}".format(commit_message, from_hook_message))
 
     @with_rw_repo('HEAD', bare=True)
     def test_commit_msg_hook_fail(self, rw_repo):
